#
# spec file for package zpaqfranz
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           zpaqfranz
Version:        60.8
Release:        1.2
Summary:        A journaling, incremental, deduplicating archiver
License:        MIT AND SUSE-Public-Domain
Group:          Productivity/Archiving/Compression
URL:            https://github.com/fcorbelli/zpaqfranz
Source0:        https://github.com/fcorbelli/zpaqfranz/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  gcc-c++

%description
Swiss army knife for backup and disaster recovery, like 7z or RAR on
steroids,with deduplicated "snapshots" (versions). Conceptually similar to Mac
time machine, but much more efficiently.

%prep
%autosetup

%build
g++ %{optflags} \
  %ifarch %ix86
  -Dunix -DHWSHA2 \
  %elifarch s390x  \
  -Dunix -DNOJIT -DBIG \
  %else
  -Dunix -DNOJIT \
  %endif
  zpaqfranz.cpp -o zpaqfranz -pthread -lstdc++ -lm

%install
install -Dpm 0755 zpaqfranz %{buildroot}%{_bindir}/%{name}

%files
%doc README.md
%license LICENSE COPYING
%{_bindir}/%{name}

%changelog
* Sat Nov  9 2024 Andrea Manzini <andrea.manzini@suse.com>
- update to 60.8:
  * -backupzeta
    This new switch, to be used in the backup command, generates checksums
    on the fly, without reading them at the end of the .zpaq file
    creation, saving a lot of time, especially on slow disk drives like HDDs.
    The generated checksums are quite robust ("almost" XXHASH64 and CRC-32).
    In the future, it will also support encrypted volumes
  * Set the creation date of .zpaq archives to 1/1/1980
    so it is easy to quickly identify those that were not written completely
  * New hash algorithms ZETA and ZETAENC.
    Can be selected with -zeta and -zetaenc. You can find the explanation here
    https://github.com/fcorbelli/zpaqfranz/issues/139#issuecomment-2425010093
  * -destination
    With the new switch, it is possible to load a series of lines (from a text
    file) as if they were multiple -to options. The explanation is here
    https://github.com/fcorbelli/zpaqfranz/issues/136#issuecomment-2422947782
  * -nodelete
    This switch does not mark files as deleted if they are not found during the
    path scan. It is used for bulk manipulation of the file list.
    The explanation is here
    https://github.com/fcorbelli/zpaqfranz/issues/136#issuecomment-2422947782
  * -salt
    This switch forces an empty salt (i.e., 32 bytes of zeros). It is something
    you should NOT normally use. It serves as a development mechanism
    (i.e., it is something that is useful for ME, not for YOU).
  * -hdd
    With this switch, you use the computer's memory (including virtual memory,
    i.e., the swap file) to sequentially write the extracted data. It is useful
    if you have a lot of RAM or an SSD system drive and want to extract to an
    HDD. In this case, everything will first be decompressed into RAM and then
    written to the HDD, without any seeks (head movement) in the output.
    It is not suitable for gigantic files, but for medium sizes, it can halve
    the extraction time.
  * -ramdisk
    Internal for -hdd
  * fix on -input
    Minor bug fixed on Windows
  * warnings in yellows Because sometimes colours... counts...
- update to 60.7:
  * This release includes numerous new features; hopefully, not too many bugs :)
  * The license of one component has been changed to make it compatible with
    Fedora policies.
  * It's now possible to create a file with a list of errors to reduce
    confusion in the logs (-errorlog).
  * Captchas can be bypassed using -nocaptcha.
  * By default, it now uses the number of physical CPUs (no Hyperthread); you
    can use -ht to bypass this and return to the previous method.
  * Error messages now appear in red by default.
  * zpaqfranz tracks memory usage (more or less) in the very last output line.
  * It shows more understandable error messages (!) when running out of memory
    due to overly small fragments.
  * Output lines have been renumbered.
  * With the -input switch, you can load a list of files to be added.
  * The -715 switch in the l (list) command restores an output that is nearly
    identical, binary-wise, to zpaq 7.15.
  * In the sum command, the -home switch replaces -checksum.
* Sat Sep  7 2024 Dirk Müller <dmueller@suse.com>
- update to 60.6:
  * Better -stdin management
    Now files added with -stdin should be deduplicated as well as
    those added manually (up to the previous version the
    deduplicator was less efficient, for a whole series of
    reasons long to explain)
  * New comparehex command
    This command performs an operation that happens very
    frequently, namely comparing two lines (typically HASH codes)
    present in two files. If the codes are the same it exits with
    OK. You can also impose the expected length of the hash.
  * Counts within more than one file the occurrences of a certain
    string, and returns OK if the number is the expected one In
    essence, within a log file, it counts how many positive
    results there are.
  * If you don't select a string to search for, it will use the
    default one for OKs with the -big switch
  * During program termination with Control-C press, a better
    management of the deletion of files created with -chunk is
    performed.
  * It might also perform rollback of .zpaq files, maybe in the
    future.
  * Apparently it should work in a portable way across various
    platforms, or at least I hope so.
  * The problem of terminating a multithreaded system based on a
    condition is not trivial, even from a performance
    perspective. I used "dirty tricks", we'll see in the future.
  * Improvement in the creation of temporary files, for the use
    of multiple zpaqfranz processes simultaneously
  * Temporary files are created inside different subfolders
    (marked with mtime) in order to reduce the risk of
    "collision" if multiple zpaqfranz are launched simultaneously.
  * Used to automate many convenient functions for backup logs.
  * Use -find/replace to fix path (if needed); -ssd for M/T
  * The t command (without a path) do NOT read something from
    filesystem
  * You have to use the t command WITH a path (or use the -verify
    switch)
  * The brand new -crc32 switch is makes a triple CRC-32
    comparing, READING from the filesystem.
  * In this case, the -find and -replace switches can be useful
    to transform the stored paths into physical paths (if they
    are different)
  * New -csv and -csvhf switches for l (list)
  * -external in add
  * hashdeep format
    But it's still using zpaqfranz: any bugs could still affect
    its reliability
  * For delicate situations we use an external program, which
    therefore doesn't have the possible bugs of zpaqfranz, such
    as hashdeep (in the Windows version hashdeep64 is faster)
* Wed Jun 19 2024 Dirk Müller <dmueller@suse.com>
- update to 59.8:
  * _The l (list) command use a new format; filesize is now ...
    autosized; estimated ratio is written, better infos with -all
    switch, do not show attrs by default
  * Do not add() if the X folder does not exists
  * -nocolors on redirect
- update to 59.7:
  * Less used RAM enumerating files
  * zfssize command
  * switch -pause in add
  * updated info on vss
  * AMD 3950X benchmark added
  * New hash command
  * Command s with -home switch
  * Command hash with -orderby
  * add -ignore switch
  * substituted /sec with /s
  * minor fixes in -noeta
  * fixes in update (on *nix)
- update to 59.4:
  * crop command
  * c command -checksum switch
- update to 59.3:
  * New update command
    [#]## Warning. Downloading executable programs from the
    Internet is potentially dangerous. Always choose a reliable
    source (such as github or sourceforce), or directly my site
    https://www.francocorbelli.it/zpaqfranz/win64/
* Sun Mar 17 2024 Dirk Müller <dmueller@suse.com>
- update to 59.2:
  * Some minor "things"
* Sun Feb 18 2024 Andrea Manzini <andrea.manzini@suse.com>
- update to 59.1:
  This new build is of a new branch, includes several new features to be tested, and may therefore contain bugs.
  * -chunk option to create multipart fixed-size archives
  * -fast: store inside zpaq archive a "kind of" file list (to be developed)
  * ADS filelists (NTFS alternate data stream)
  * Getting password from console is changed, now should be run... everywhere
  * Colors on Windows
  * Smarter debug
  * -longpath files support on Windows
* Sun Nov 26 2023 Dirk Müller <dmueller@suse.com>
- update to 58.11:
  * Undocumented -collision -kill, to be implemented
  * Quickly check and (sometimes) recovery from SHA-1 collision
  * Warning-hunting on 15+ years compiler
  * Removed a fake compiler warning
  * 32 bit gcc fix, or better workaroud
    https://bugzilla.redhat.com/show_bug.cgi?id=2238781
  * disclaimer after help for USE THE DOUBLE QUOTES, LUKE!
  * changed $day, $hour... to %%day, %%hour ( Linux does not like
    '$' very much )
  * PowerPC fix
  * New switch -home in a command (add)
  * Stripped of about everything from zpaqfranz repository
  * Moved to zpaqfranz-stuff (for license reason when 'packaged')
  * the subfolders, much smaller git
  * Fixed some typo in zpaqfranz.cpp source code, added some
    greetings
* Tue Aug 22 2023 Martin Pluskal <mpluskal@suse.com>
- Initial package for version 58.8
